# Roadmap

- Add optional timing instrumentation
  - look for any bad cases in current test suite, another round of optimisation
- Allow configuring a time budget rather than max search iterations
- Allow set budgets globally implicitly via env var
